@@ -2,8 +2,8 @@
 import sys
 
 from django.core.exceptions import ImproperlyConfigured
-from django.utils import six
 from django.utils.importlib import import_module
+import six
 
 
 def import_by_path(dotted_path, error_prefix=''):
@@ -26,7 +26,7 @@ def import_by_path(dotted_path, error_prefix=''):
     try:
         attr = getattr(module, class_name)
     except AttributeError:
-        raise ImproperlyConfigured('%sModule "%s" does not define a "%s" attribute/class' % (
-            error_prefix, module_path, class_name))
+        raise ImproperlyConfigured('%sModule "%s" does not define a '
+                                   '"%s" attribute/class' %
+                                   (error_prefix, module_path, class_name))
     return attr
-
